## A3L Authentication Sample App 

### Configuring Google API Console:

Before integrating A3L Authentication into your app, you need to set up a project and configure it in Google API console.
To learn how to configure a Google API Console project for Authentication, see <a href="https://developers.google.com/identity/sign-in/android/start-integrating#configure_a_project">Configure a Google API Console project</a>
in the Google developer documentation. Post following the steps mentioned, note down the following for usage in the app.

1. Note down the Android Client ID from the API Console. Go to your project in Google’s API Console and 
you can find the Android Client ID <a href="https://console.cloud.google.com/apis/credentials">here</a>.
2. (Optional) In case you also need the ID token, you will need a OAuth 2.0 Client ID. 
You can follow the instructions <a href="https://developers.google.com/identity/sign-in/android/start-integrating#get_your_backend_servers_oauth_20_client_id">here</a> 
to get your OAuth 2.0 Client ID. 

### Configuring Sample App:

The sample requires Android type Client ID and OAuth 2.0 Client ID (Optional), provided by the Google API Console. 
Replace the <code>PREFIX</code> and <code>SERVER_CLIENT_ID</code> in the <code>app/src/res/values/strings.xml</code> with Android type Client ID Prefix and OAuth2.0 Client ID respectively. 
Replace the values in <code>strings.xml</code>, which will have the default values like this:

```
<string name="app_client_id">PREFIX</string>
<string name="server_client_id">SERVER_CLIENT_ID</string>
```

Also replace the “PREFIX” in value appAuthRedirectScheme with the Android type Client ID prefix, 
present in app’s build.gradle. The default looks like the following:

```
defaultConfig {
// Other Configuration
    manifestPlaceholders = [
        'appAuthRedirectScheme': 'com.googleusercontent.apps.<PREFIX>'
    ]
// Other Configuration
}
```
#### Notes:

>In both the places where <code>PREFIX</code> must be replaced, replace it with only the Prefix of your Android type Client ID. 
Post generating the Android type Client ID as said in "Configuring Google API Console" section, your client ID will look something like 
<code>PREFIX.apps.googleusercontent.com</code>, where instead of PREFIX you will have a alphanumeric string unique to your app. 
You will only be providing this alphanumeric part in the place of PREFIX.

>The <code>SERVER_CLIENT_ID</code> should be OAuth 2.0 Client ID provided in full, that is generated when you create a web client ID as mentioned in the section "Configuring Google API console".

When building the project, if you run into an "SDK location not found" error, add a line in the local.properties file at the root of the project to include your Android SDK location.
For example:

* On Windows, add the line: sdk.dir=C:\\Users\\{username}\\AppData\\Local\\Android\\sdk
* On Mac, add the line: sdk.dir=/Users/{username}/Library/Android/sdk

Replace {username} with your username.

### Sample app testing:

1. After configuring as said above, build the app.
2. Install the app on an Android device that has Google Play Service enabled or on a FireOS device.
3. Open the app. You will be seeing an app with A3L Authentication title and a Sign In With Google Button.
4. Click on the button and it redirects you to the respective sign in flow according to the device currently the app is installed in.
5. Post signing in, you will be able to see your profile details displayed in the space between SignInButton previously present and the A3L Authentication title.
6. You will be able to see two new buttons, Revoke Access and Sign Out. Click on either of these to verify the functionality if needed. 

